A function to compute the elbow point given a set of points
Source:R/utilityFunctions.R
dot-computeElbow.RdA function to compute the elbow point given a set of points
R/utilityFunctions.R
dot-computeElbow.RdA function to compute the elbow point given a set of points